pub struct ThreadSafeCacheImpl<K: Eq + Hash, V> {
pub cache: HashMap<K, (V, u128)>,
pub expiration_set: BTreeMap<u128, Vec<K>>,
pub max_size: i32,
pub current_size: i32,
}
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.