pub struct NetworkCache<K: Eq + Hash + DeserializeOwned, V: DeserializeOwned> {
pub tcp_stream: TcpStream,
pub rt: Runtime,
pub phantom_data: PhantomData<(K, V)>,
}
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.